@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2014 Luca Falavigna
+# Copyright (C) 2007-2015 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -18,33 +18,37 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import os
-from configparser import ConfigParser
 from argparse import ArgumentParser
-from logging import basicConfig as log, debug, error, getLogger, warning
+from configparser import ConfigParser
+from fcntl import flock, LOCK_EX, LOCK_NB, LOCK_UN
+from logging import basicConfig as log, debug, error, getLogger, info, warning
 from logging import ERROR, WARNING, INFO, DEBUG
+from subprocess import check_call as call, CalledProcessError
 from time import sleep
 
-from .build import FullBuild
+from .build import Build
 from .commands import Command
+from .configuration import Parser
+from .exceptions import DebomaticConffileError, DebomaticError
+from .gpg import GPGKeys
 from .modules import Module
 from .process import Process, ThreadPool
 
 
-class Debomatic(Process):
+class Debomatic(Parser, Process):
 
     def __init__(self):
         self.daemonize = True
         self.setlog('%(levelname)s: %(message)s')
         self.conffile = None
-        self.configvers = '013a'
         self.opts = ConfigParser()
-        self.rtopts = ConfigParser()
+        self.dists = ConfigParser()
         parser = ArgumentParser()
         parser.add_argument('-c', '--configfile', metavar='file', type=str,
                             nargs=1, help='configuration file for Deb-o-Matic')
-        parser.add_argument('-n', '--no-daemon', action='store_true',
-                            help='do not launch Deb-o-Matic in daemon mode')
-        parser.add_argument('-q', '--quit-process', action='store_true',
+        parser.add_argument('-i', '--interactive', action='store_true',
+                            help='launch Deb-o-Matic in interactive mode')
+        parser.add_argument('-q', '--quit', action='store_true',
                             help='terminate Deb-o-Matic processes')
         args = parser.parse_args()
         if os.getuid():
@@ -52,57 +56,44 @@ class Debomatic(Process):
             exit(1)
         if args.configfile:
             self.conffile = args.configfile[0]
-        if args.no_daemon:
+        if args.interactive:
             self.daemonize = False
-        self.default_options()
-        self.packagedir = self.opts.get('default', 'packagedir')
-        if not os.path.isdir(self.packagedir):
-            error(_('Unable to access %s directory') % self.packagedir)
+        try:
+            self.parse_configfiles()
+        except DebomaticConffileError:
             exit(1)
-        self.pool = ThreadPool(self.opts.getint('default', 'maxbuilds'))
-        self.logfile = self.opts.get('default', 'logfile')
-        if args.quit_process:
+        self.incoming = self.opts.get('debomatic', 'incoming')
+        if not os.path.isdir(self.incoming):
+            error(_('Unable to access %s directory') % self.incoming)
+            exit(1)
+        self.pool = ThreadPool(self.opts.getint('debomatic', 'threads'))
+        self.logfile = self.opts.get('debomatic', 'logfile')
+        if args.quit:
             self.shutdown()
             exit()
         self.setlog('%(levelname)s: %(message)s',
-                    self.opts.get('default', 'loglevel'))
-        self.mod_sys = Module((self.opts, self.rtopts, self.conffile))
-        debug(_('Startup hooks launched'))
-        self.mod_sys.execute_hook('on_start', {})
-        debug(_('Startup hooks finished'))
+                    self.opts.get('debomatic', 'loglevel'))
+        gpg = GPGKeys()
+        try:
+            gpg.check_keys()
+        except DebomaticError:
+            info(_('Creating sbuild keys'))
+            try:
+                call(['sbuild-update', '--keygen'])
+            except CalledProcessError:
+                error(_('Failed to create sbuild keys'))
+                exit(1)
+        self.mod_sys = Module(self.opts)
+        self.mod_sys.execute_hook('on_start')
         try:
             self.startup()
-        except RuntimeError:
+        except DebomaticError:
             error(_('Another instance is running, aborting'))
             exit(1)
 
-    def default_options(self):
-        defaultoptions = ('builder', 'debootstrap', 'packagedir', 'configdir',
-                          'architecture', 'maxbuilds', 'pbuilderhooks',
-                          'inotify', 'sleep', 'logfile', 'loglevel')
-        if not self.conffile:
-            error(_('Configuration file has not been specified'))
-            exit(1)
-        if not os.path.exists(self.conffile):
-            error(_('Configuration file %s does not exist') % self.conffile)
-            exit(1)
-        self.opts.read(self.conffile)
-        if (not self.opts.has_option('internals', 'configversion') or
-                not self.opts.get('internals', 'configversion') ==
-                self.configvers):
-            error(_('Configuration file is not at version %s') %
-                  self.configvers)
-            exit(1)
-        for opt in defaultoptions:
-            if (not self.opts.has_option('default', opt) or
-                    not self.opts.get('default', opt)):
-                error(_('Set "%(opt)s" in %(conffile)s') %
-                      {'opt': opt, 'conffile': self.conffile})
-                exit(1)
-
     def launcher(self):
         self.queue_files()
-        if self.opts.getint('default', 'inotify'):
+        if self.opts.getboolean('debomatic', 'inotify'):
             try:
                 self.launcher_inotify()
             except ImportError:
@@ -125,33 +116,37 @@ class Debomatic(Process):
 
         wm = pyinotify.WatchManager()
         notifier = pyinotify.Notifier(wm, PE(self))
-        wm.add_watch(self.packagedir, pyinotify.IN_CLOSE_WRITE)
+        wm.add_watch(self.incoming, pyinotify.IN_CLOSE_WRITE)
         debug(_('Inotify loop started'))
         notifier.loop()
 
     def launcher_timer(self):
         debug(_('Timer loop started'))
         while True:
-            sleep(self.opts.getint('default', 'sleep'))
+            sleep(self.opts.getint('debomatic', 'sleep'))
             self.queue_files()
 
     def queue_files(self, filelist=None):
         if not filelist:
             try:
-                filelist = os.listdir(self.packagedir)
+                filelist = os.listdir(self.incoming)
             except OSError:
-                error(_('Unable to access %s directory') % self.packagedir)
+                error(_('Unable to access %s directory') % self.incoming)
                 exit(1)
         for filename in filelist:
             if filename.endswith('.changes'):
-                b = FullBuild((self.opts, self.rtopts, self.conffile),
-                              package=filename)
-                self.pool.schedule(b.run)
-                debug(_('Thread for %s scheduled') % filename)
+                with open(os.path.join(self.incoming, filename)) as fd:
+                    try:
+                        flock(fd, LOCK_EX | LOCK_NB)
+                        flock(fd, LOCK_UN)
+                    except IOError:
+                        pass
+                    else:
+                        b = Build(self.opts, self.dists, changesfile=filename)
+                        self.pool.schedule(b.run)
+                        debug(_('Thread for %s scheduled') % filename)
             elif filename.endswith('.commands'):
-                c = Command((self.opts, self.rtopts, self.conffile),
-                            self.pool, filename)
-                c.process_command()
+                Command(self.opts, self.dists, self.pool, filename)
 
     def setlog(self, fmt, level='info'):
         loglevels = {'error': ERROR,
