@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2014 Luca Falavigna
+# Copyright (C) 2007-2015 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -19,8 +19,10 @@
 
 import os
 from fcntl import flock, LOCK_EX, LOCK_NB, LOCK_UN
-from re import findall, DOTALL
-from subprocess import Popen, PIPE
+from re import findall, match, DOTALL
+from subprocess import check_output, Popen, PIPE, CalledProcessError
+
+from .exceptions import DebomaticError
 
 
 class GPG:
@@ -30,7 +32,7 @@ class GPG:
         self._file = file
         self._error = None
         if self._opts.has_option('gpg', 'gpg'):
-            self._gpg = self._opts.getint('gpg', 'gpg')
+            self._gpg = self._opts.getboolean('gpg', 'gpg')
         else:
             self._gpg = False
         self._sig = None
@@ -50,7 +52,7 @@ class GPG:
             if not os.path.isfile(self._keyring):
                 self._keyring = None
                 self._error = _('Keyring not found')
-                raise RuntimeError
+                raise DebomaticError
         gpgresult = Popen(['gpgv', '--keyring', self._keyring, self._file],
                           stderr=PIPE).communicate()[1]
         signature = findall(b'Good signature from "(.*) <(.*)>.*"', gpgresult)
@@ -58,7 +60,7 @@ class GPG:
             self._sig = signature[0]
         else:
             self._error = _('No valid signatures found')
-            raise RuntimeError
+            raise DebomaticError
 
     def _strip_signature(self):
         with open(self._file, 'r') as fd:
@@ -78,3 +80,35 @@ class GPG:
 
     def error(self):
         return self._error
+
+
+class GPGKeys:
+
+    def __init__(self):
+        self._private = '/var/lib/sbuild/apt-keys/sbuild-key.sec'
+        self._public = '/var/lib/sbuild/apt-keys/sbuild-key.pub'
+
+    def check_keys(self):
+        try:
+            with open(os.devnull, 'w') as fd:
+                gpgresult = check_output(['gpg', '--with-fingerprint',
+                                         self._private], stderr=fd)
+        except CalledProcessError:
+            self._error = _('%s not found') % self._private
+            raise DebomaticError
+        if not match(b'sec\s+\d+\S/\S{8}', gpgresult):
+            self._error = _('%s is not a valid GPG key') % self._private
+            raise DebomaticError
+        try:
+            with open(os.devnull, 'w') as fd:
+                gpgresult = check_output(['gpg', '--with-fingerprint',
+                                         self._public], stderr=fd)
+        except CalledProcessError:
+            self._error = _('%s not found') % self._public
+            raise DebomaticError
+        if not match(b'pub\s+\d+\S/\S{8}', gpgresult):
+            self._error = _('%s is not a valid GPG key') % self._public
+            raise DebomaticError
+
+    def error(self):
+        return self._error
